@@ -7,5 +7,5 @@ fit <- curvefits(
     INPUT, brks2,
     methods = c("AG", "Beck", "Elmore", "Zhang"), #,"klos", "Gu"
     wFUN = wFUN,
-    nextent = 2, maxExtendMonth = 2, minExtendMonth = 1, minPercValid = 0.2,
+    nextend = 2, maxExtendMonth = 2, minExtendMonth = 1, minPercValid = 0.2,
     print = TRUE, verbose = FALSE)
