@@ -4,6 +4,7 @@ source('helper_MOD13A1.R')
 # source('tests/testthat/helper_MOD13A1.R')
 lambda   <- init_lambda(INPUT$y) # lambda for whittaker
 
+# `season` produce a pdf file here
 param = listk(
     INPUT,
     rFUN = wWHIT, wFUN = wBisquare, iters = 2,
@@ -14,7 +15,14 @@ param = listk(
     max_MaxPeaksperyear =2.5, max_MinPeaksperyear = 3.5
 )
 
+
+test_that("`season` with wWHIT and calendarYear", {
+    param$calendarYear <- TRUE
+    expect_silent(brks <- do.call(season, param))
+})
+
 test_that("`season` with wWHIT", {
+    param$calendarYear <- FALSE
     expect_silent(brks <- do.call(season, param))
 })
 
